import React from 'react';
import useFunction from './useFunction';
export declare type SelectorFn<Value, Selected> = (value: Value) => Selected;
export interface ContainerProviderProps<State = void> {
    initialState?: State;
}
/**
 * Create a container with `useHook`
 */
export declare function createContainer<Value, State = void>(useHook: (initialState?: State) => Value): {
    Context: React.Context<Value | null>;
    Provider: React.FC<ContainerProviderProps<State>>;
    /**
     * Filter the required return value through the hook.
     * @param selector
     * @example
     * const count = useSelector(state => state.count)
     */
    useSelector: <Selected>(selector: SelectorFn<Value, Selected>) => Selected;
    /**
     * Filter the required values in the array, provided that `state` must be `object`.
     * @param selected
     * @example
     * const { count, setCount } = usePicker(['count', 'setCount'])
     */
    usePicker: <S extends keyof Value>(selected: S[]) => Pick<Value, S>;
    /**
     * Provider wrapper.
     * @param OriginComponent
     */
    withProvider: <T>(OriginComponent: React.FC<T>) => React.FC<T>;
};
export { useFunction };
